@@ -329,7 +329,11 @@ class Recipe(Scripts):
         else:
             reqs, ws = self.working_set()
             sources = [d.location for d in ws if d.key in reqs]
+        ignore_packages = options.get('ignore-packages', '').split()
         for s in sources:
+            for package in ignore_packages:
+                if package in s:
+                    continue
             copytree(s, options['app-directory'], hasattr(os, 'symlink'),
                      exclude=options.get('exclude', '').split())
 
